% given the results of ConvolutionSearch Relevant Clones
% find the regions of interest
%
% param.region = 'frac' (0.9, 1, etc, i.e. 90% 100% )
%                or 'num' ( 2, etc... in at least 2 windowsizes')

function [RW,T,Tok]=Convolution_findRegions (relevantW,ch,param,labels)
	
% load the cumulative position of the chromosomes to determine the x axis limit
	[sch,tmp1,tmp2,e]=textread('chromStartEnd.txt','%s%u%s%u','delimiter',',');
	ekb=round(e./1000); 
	cumekb1= [1;cumsum(ekb)]; cumekb1(end)=[];
	
	if isempty(ch);
		warning('no ch is given: the all genome is considered')
		x1=cumekb1(1); x2=cumekb1(end);
	%	filename=[labels.filename,clonenum,'_all.eps'];
	else
		x1=cumekb1(ch); x2=cumekb1(ch+1);
	%	filename=[labels.filename,clonenum,'_ch',num2str(ch),'.eps'];
	end
	
	
	chgrid=[x1:x2];
	
	% collect all the relevant start and end position in the given
        % ch of interest for the different window sizes and make a
        % relevantgrid vector with the relevant locations
	chhist=zeros(length(relevantW),length(chgrid));
	RW=[];
	for i=1:length(relevantW)
		tmp=relevantW{i};
		tmp=uint32(tmp);
		if ~isempty(tmp)
		% take only the window that don't exceed the ch of interest
		index=[find(tmp(:,1)>x1 &tmp(:,1)<x2);find(tmp(:,2)>x1 &tmp(:,2)<x2)];
		index=unique(index);
		% relevant grid position for the given iesima relevantW 
		tmpgrid=[];
		for ind=1:length(index)
			tmpgrid=[tmpgrid,tmp(index(ind),1):tmp(index(ind),2)]	;
		end
		relevantgrid=unique(tmpgrid);
		[c,ichgrid]=intersect(chgrid,relevantgrid);
		 
		chhist(i,ichgrid)=ones(1,length(ichgrid));
		%else chhist=0;
		end
		
	end
	
	T=sum(chhist,1);
	
        switch param.region
	 case 'frac'
	  % normalize and compute the 
	  Tn=T./sum(T);
	  Tthr=unique(Tn);
	  Tnew=1.1; c=1;
	  while Tnew>param.th
		  Tnew=sum(Tn(find(Tn>=Tthr(c))));
		  % trick to work also for th=1
		  if Tnew>1 
			  Tnew=round(Tnew) ;
		  end;
		  c=c+1;
	  end
	  Tok=Tn>=Tthr(c);
	 case 'num'
	  % old Tok=T>=param.th;
	  Tok=T>=param.numth;
	end
	
%	chhistsum([1,end])=0; % trik to have always a local maxima
%	[max_pos_left, max_pos_right, max_val] = interp_local_max(chhistsum>th);
	
        Tok([1,end])=0; % trik to have always a local maxima
%try
	if sum(Tok)==0
		fprintf('the minumum number of window sizes has not been reached \n')
	else
		[max_pos_left, max_pos_right, max_val] = interp_local_max(Tok);
		RW=[chgrid(max_pos_left)',chgrid(max_pos_right)'];
	end
%catch
%	fprintf('error in Convolution_findRegions.m')
%	keyboard
%end

	% figure with the boundary of the relevant region
% $$$ 	figure
% $$$ 	hold on 
% $$$ 	plot(T);
% $$$ %	plot([0:200000],th*ones(1,200001),'r')
% $$$         plot([1:length(Tok)],Tok,'r');
% $$$ 
% $$$ % $$$ 	set(gca,'XTickLabel',{});
% $$$ % $$$ 	set(gca,'YTick',[ 1:22]);  
% $$$ 	legend('sum over window sizes','relevant region')
% $$$ 	ylabel('number of folds in which the location is relevant')
% $$$ 	title(labels.title);
% $$$ 
% $$$ 	axis([1 length(chgrid) 0 max(T)]);
% $$$ 	grid on 
		 
	