% newest version with 
% lodwyk suggestion: best CORRELATION GENE-CLONEs in the region

% ch = chromosome of interest
% % param.region = 'frac' (0.9, 1, etc, i.e. 90% 100% )
%                or 'num' ( 2, etc... in at least 2 windowsizes')


function [generw] =Convolution_findRelevantGene3 (mrna,rel,l,relevantW,ch,param,labels)
	
	% FIND RELEVANT REGION BASED ON CGH and windows for the 
% given: ch chromosome of interest and 
% th (percentage of the normalized density of window sizes where the location is judged relevant)
	[RW]=Convolution_findRegions (relevantW,ch,param,labels);
	
	if ~isempty(RW) 
		% FIND GENES IN THIS REGION
		geneok=[]; bestcorr.p=[];bestcorr.r=[]; bestrelcloneindex=[]; bestrelclonedist=[];
		for i=1:size(RW,1)
			m=repmat(RW(i,:)',1,length(mrna.ch));
			igeneok=find(mrna.kbcumdis>= m(1,:) & mrna.kbcumdis<= m(2,:));
			geneok=[geneok,igeneok];
			
			% LODEWYK SUGGESTION: best CORRELATION GENE-CLONEs in the region
			% find the relevant clones in the region
			irel=find(rel.kbcumdis>=RW(i,1) &rel.kbcumdis<=RW(i,2));
			
			% sometimes irel can be empty therefore take the
                        % relevant clones from the adiacent regions
			if isempty(irel)
				irel1=[];irel2=[];
				if i>=2
					irel1=find(rel.kbcumdis>=RW(i-1,1) &rel.kbcumdis<=RW(i-1,2));
				end
				if i<size(RW,1)
					irel2=find(rel.kbcumdis>=RW(i+1,1) &rel.kbcumdis<=RW(i+1,2));
				end	
				irel=[irel1,irel2];
			end
			% if irel is still empty
			if isempty(irel) & ~isempty(igeneok)
				irel=find(rel.ch==mrna.ch(igeneok(1)));
			end
			
			
			% for each gene compute the best correlation with the clones
			for g=1:length(igeneok)
				gcorr.r=[]; gcorr.p=[];
				for c=1:length(irel)
					[r,p]=corrcoef(mrna.data(:,igeneok(g)),rel.data(:,irel(c)));
					gcorr.r=[gcorr.r,r(1,2)];
					gcorr.p=[gcorr.p,p(1,2)];
				end
				[tmp,igcorr]=max(gcorr.r);
				bestcorr.p=[bestcorr.p,gcorr.p(igcorr)];
				bestcorr.r=[bestcorr.r,gcorr.r(igcorr)];
				bestrelcloneindex=[bestrelcloneindex,irel(igcorr)]; 
				bestrelclonedist=[bestrelclonedist,abs(rel.kbmidpos(irel(igcorr))-mrna.kbmidpos(igeneok(g)))];
			end
		end	
		%~~~~~~~~~~~~~~~~~~~~~
		% MAP GENES TO THE CLOSEST RELEVANT CLONES
		d=mapgene2clone (rel.kbcumdis,rel.ch,mrna.kbcumdis(geneok),mrna.ch(geneok));
		% d(:,1)=index of the closest clone
		% d(:,2)=distance from the closest clone
		
		% COMPUTE THE CORRELATION GENE-closestCLONE
		try
			corr.r=[];corr.p=[];
			for i=1:length(geneok)
				[r,p]=corrcoef(mrna.data(:,geneok(i)),rel.data(:,d(i,1)));
				corr.r=[corr.r,r(1,2)];
				corr.p=[corr.p,p(1,2)];
			end
		catch
			keyboard
		end

		%~~~~~~~~~~~~~~~~~~~~~
		% new addition :)
		
		% COMPUTE THE TTEST2
		% since i got in trable with the indexes i'm not sorting the
		% results of the ttest
		%	[I,C1,C2] = px_switch_criterion(mrna.data(:,geneok),l,[],'ttest2');
		% note C1=geneok(I), not C1(I)=geneok !!!
		lu=unique(l);
		if size(lu)~=2 error('there are more then 2 classes!'); end
		
		class1=find(l==lu(1));
		class2=find(l==lu(2));
		P=[]; T=[];
		X=mrna.data(:,geneok);
		for i=1:size(X,2)
			[h,p,ci,stats] = ttest2(X(class1,i),X(class2,i),0.05,0);
			P=[P,p]; T=[T,stats.tstat]; 
		end
		
		
		% COMPUTE THE PRODUCT CORR-TTEST AND RANK THE GENE ACCORDINGLY
		ttcorr=corr.p.*P;
		[s,ind]=sort(ttcorr);
		
		% SAVE THE RESULTS
		generw.index=geneok(ind);
		% correlation with closest clone
		generw.corr=corr.r(ind);
		generw.pcorr=corr.p(ind);
		% ttest
		generw.pttest=P(ind);
		% product ttest-corr
		generw.pttcorr=s;
		% index and distance of the closest clone
		generw.relcloneindex=d(ind,1)';
		generw.relclonedistance=d(ind,2)';
		
		try
		% best correlation in the region
		generw.bestcorr=bestcorr.r(ind);
		generw.pbestcorr=bestcorr.p(ind);
		% product ttest-bestcorr
		generw.pttbestcorr= generw.pttest .*generw.pbestcorr;
		% index and distance of the best correlated clone
		generw.bestrelcloneindex=bestrelcloneindex(ind);
		generw.bestrelclonedistance= bestrelclonedist(ind);
		catch
			warning('aiutooo ... Convolution_find')
			keyboard
		end
	else generw.index=[];
		
	end
	
	
	