%BBWRITE write cell arrays or matrices into a CSV file 
%
%   BBWRITE(FILENAME,A,B,...)
%
% INPUT
%   FILENAME    name of the file to be created and used for writing
%   A,B         cell arrays or matrices to be written
%
% DESCRIPTION 
% BBWRITE allows for writing content of cell arrays and matrices into a
% comma-separated file (CSV). The file called FILENAME is created
% (overwritten) in the process. Only string or numerical entries (integers)
% are supported. All inputs must have equal number of rows.
%
% EXAMPLE
% a={'aaa',3;'bb',5}; b=[34;56]; 
% bbwrite('/tmp/out.txt',a,b);

function bbwrite(name,varargin)
    
    fid=fopen(name,'w');
    format='';
    ev='';
    for i=1:length(varargin)
	if size(varargin{i},1)~=size(varargin{1},1)
	    error('all inputs must have equal number of rows');
	end
	t=varargin{i};
	if iscell(t)
	    for c=1:size(t,2)
		t2=t{1,c};
		if isnumeric(t2)
		    format=[format ',%d'];
		    ev=[ev sprintf(',varargin{%d}{i,%d}',i,c)];
		elseif ischar(t2)
		    format=[format ',%s'];
		    ev=[ev sprintf(',char(varargin{%d}{i,%d})',i,c)];
		end
	    end
	elseif isnumeric(t)
	    format=[format ',%d'];
	    ev=[ev sprintf(',varargin{%d}(i,:)',i)];
	end
    end
    format=format(2:end);
    ev=ev(2:end);

    rc=size(varargin{1},1);
%    keyboard
    for i=1:rc
	eval(['fprintf(fid,''' format '\n'',' ev ');']);
    end
    fclose(fid);
    