% description:
% - consider a window centered at each relevant clone and 6 more points
% at the boundaries of the window
% - apply the hypergeometric there
% - correct for multiple testing

% $$$ param.window= 2000; % length of half window
% $$$ param.th = 0.05 ;   % threshold for the significant regions
% $$$ param.delta=0.2;
%

function [region, relevantwindow, relevantCh]=window_on_relevant_clonesOK (cgh,rel,param)
	% start and end position for the ch
	[sch,tmp1,tmp2,e]=textread('chromStartEnd.txt','%s%u%s%u','delimiter',',');
	ekb=round(e./1000); 
	cumekb1= [1;cumsum(ekb)]; cumekb1(end)=[];
	

% preliminary: global paramiter for the hyper	
	M = length(cgh.ch);
	K = length(rel.ch);
	
	% shift from the end of the window as new center for the window 
%	delta = param.window*param.delta;

	
% for each chromosome evaluate:	
	ch=unique(rel.ch);
	SAMPLE_POINT=[]; SAMPLE_POINTch=[];SAMPLE_POINTH=[];
	for i=1: length(ch)
		chclone=find(rel.ch==ch(i));
		
		% sampling points for the window
		sample_point=[];

		for s=1:length(chclone)
			sample_point=[sample_point ,[rel.kbcumdis(chclone(s)),...
		    rel.kbcumdis(chclone(s))-param.window,...
		    rel.kbcumdis(chclone(s))+param.window]];
		end
		  
    		sample_point=unique(sample_point);

		% verify that the window is in the boundary of the chromosome
		st=sample_point - (param.window*ones(1,length(sample_point)));
		en=sample_point + (param.window*ones(1,length(sample_point)));
		indBADsample=find(st< cumekb1(ch(i))*ones(1,length(st)) |...
				  en> cumekb1(ch(i)+1)*ones(1,length(en)));     
		% remouve eventual windows that exceed the boundary of
                % the chromosome
		if ~isempty(indBADsample)
		%	fprintf('too long')
			sample_point(indBADsample)=[];
		end
		
		% compute the Hyper
		indNoHyper=[];
%	keyboard	
		for w=1:length(sample_point)
		
			wclone = find(cgh.kbcumdis>=sample_point(w)-param.window & cgh.kbcumdis<=sample_point(w)+param.window);
			wrel = find(rel.kbcumdis>=sample_point(w)-param.window & rel.kbcumdis<=sample_point(w)+param.window);
		
			N = length(wclone);
			x = length(wrel);
		
			% If there are relevant clones => hyper
			if x~=0
% $$$ 			p=hygecdf(x-1,M,K,N); % prob of having 0-(x-1)
% $$$                                               % random
% $$$ 			P(i)=1-p; Po(i)=1-hygecdf(0,M,K,N);		      
% $$$ 			H(i) = (1-p)./(1-hygecdf(0,M,K,N));
                        % better the function of Theo: note that i get directly
			% the p i want! 
  			        p = hygecdf3(x,M,K,N);
			        SAMPLE_POINTH=[SAMPLE_POINTH,p];
			else
				
				indNoHyper=[indNoHyper,w];
			%	warning('there are not relevant clones in your window')
			end
			
		end	
		sample_point(indNoHyper)=[]; 
		SAMPLE_POINT=[SAMPLE_POINT,sample_point];
		SAMPLE_POINTch=[SAMPLE_POINTch,ch(i)*ones(1,length(sample_point))];
	end
	region.sample_point=SAMPLE_POINT;
	region.sample_point_ch=SAMPLE_POINTch;
	region.pH=SAMPLE_POINTH;
	region.param=param;

	if ~isfield(param,'regioDetection')
		param.regioDetection='minW';
	end
%keyboard	
	switch param.regioDetection
	 case 'mergeW'
	  % FIRST APPROACH: merge the windows
	  % Bonferroni correction for multiple testing and identification of relevant
	  % windows
	  H=SAMPLE_POINTH.*length(SAMPLE_POINT);
	  rw=find(H>param.th);
	  
	  alpha=param.window*ones(1,length(SAMPLE_POINT));
	  relevantwindow=[SAMPLE_POINT-alpha;SAMPLE_POINT+alpha]';
	  relevantwindow(rw,:)=[];
	  relevantCh=SAMPLE_POINTch;
	  relevantCh(rw)=[]; relevantCh=unique(relevantCh);	
	  
	  out=window_reduce_redundant_windows (relevantwindow);
	  relevantwindow=out;
	  
	 case 'minW'
	  [relevantwindow,relevantch]=region_identification (region,cgh,param);
%	  relevantCh=SAMPLE_POINTch;
          relevantCh=relevantch;
	 otherwise
	  error('the way to detect the regions of aberration is unspecified')
	end
	