%IM_GAUSSF Gaussian filter of images stored in a dataset (DIP_Image)
%
%	B = IM_GAUSSF(A,S)
%	B = A*IM_GAUSSF([],S)
%
% INPUT
%   A        Dataset with object images dataset (possibly multi-band)
%   S        Desired standard deviation for filter, default S = 1
%
% OUTPUT
%   B        Dataset with Gaussian filtered images
%
% SEE ALSO
% DATASETS, DATAFILES, DIP_IMAGE, GAUSSF

% Copyright: R.P.W. Duin, r.p.w.duin@prtools.org
% Faculty EWI, Delft University of Technology
% P.O. Box 5031, 2600 GA Delft, The Netherlands


function b = im_gaussf(a,s)

	prtrace(mfilename);
	
	if nargin < 2 | isempty(s), s = 1; end
	
  if nargin < 1 | isempty(a)
    b = mapping(mfilename,'fixed',s);
    b = setname(b,'Gaussian filter');
	elseif isa(a,'dataset') % allows datafiles too
		isobjim(a);
    b = filtim(a,mfilename,s);
  elseif isa(a,'double') | isa(a,'dip_image') % here we have a single image
		a = 1.0*dip_image(a);
		b = gaussf(a,s);
	end
	
return
