%NMC Nearest Mean Classifier
% 
%   W = NMC(A)
%   W = A*NMC
%
% INPUT
%   A    Dataset
%
% OUTPUT
%   W    Nearest Mean Classifier   
%
% DESCRIPTION
% Computation of the nearest mean classifier between the classes in the
% dataset A.  The use of soft labels is supported.
%
% SEE ALSO
% DATASETS, MAPPINGS, NMSC, LDC, FISHERC, QDC, UDC 

% Copyright: R.P.W. Duin, r.p.w.duin@prtools.org
% Faculty EWI, Delft University of Technology
% P.O. Box 5031, 2600 GA Delft, The Netherlands

% $Id: nmc.m,v 1.6 2007/09/09 21:26:53 duin Exp $

function W = nmc(a)
	
	prtrace(mfilename);
	
	if nargin < 1 | isempty(a)
		W = mapping(mfilename);
		W = setname(W,'Nearest Mean');
		return
	end
	
	islabtype(a,'crisp','soft');
	isvaldfile(a,1,2); % at least 1 object per class, 2 classes

	[m,k,c] = getsize(a);

	if c == 2      % 2-class case: store linear classifier
		u = meancov(a);
		u1 = +u(1,:);
		u2 = +u(2,:);
		R = [u1-u2]';
		offset =(u2*u2' - u1*u1')/2;
		W = affine([R -R],[offset -offset],a,getlablist(a));
		W = cnormc(W,a);
		W = setname(W,'Nearest Mean');
	else           % multiclass case, store as 1-nn classifier, best thing to do?
		if all(classsizes(a) > 1)
			p = getprior(a);
			U = zeros(c,k);
			V = zeros(c,k);
			for j=1:c
				b = seldat(a,j);
				U(j,:) = +mean(b);
				V(j,:) = +var(b);
			end
			G = mean(V'*p') * eye(k);
			w.mean = +U;
			w.cov = G;
			w.prior = p;
			W = normal_map(w,getlablist(a),k,c);
			W = setname(W,'Nearest Mean');
			W = setcost(W,a);
		else
			u = meancov(a);
			W = knnc(u,1);
			W = setname(W,'Nearest Mean');
		end
		
	end
	
	W = setcost(W,a); 
	
	return

