%REJECTC Construction of a rejecting classifier
%
%   W = REJECTC(A,W,FRAC,TYPE)
%
% INPUT
%   A      Dataset
%   W      Trained or untrained classifier
%   FRAC   Fraction to be rejected. Default: 0.05
%   TYPE   String with reject type: 'ambiguity' or 'outlier'.
%          'a' and 'o' are supported as well. Default is 'a'.
%
% OUTPUT
%   W     Classifier
%
% EXAMPLE
% a = gendatb
% w = ldc(a);
% v = rejectc(a,w,0.2);
% scatterd(a);
% plotc(w);
% plotc(v,'r')
%
% REMARK
% This is a preliminary version. It does not work properly in combination
% with other routines like TESTC.

function w_out = rejectc(a,w,frac,type)

if nargin < 4, type = 'a'; end
if nargin < 3, frac = 0.05; end

ismapping(w);
isdataset(a);

if isuntrained(w), w = a*w; end
istrained(w);

conv = getout_conv(w);
if isstr(getlablist(a))
	rejname = '';
else
	rejname = NaN;
end

switch(type)
	case{'a','ambiguity'}
		w_out = w*classc*rejectm(a*w*classc,frac,rejname);
	case{'o','outlier'}
		conv = getout_conv(w);
		if conv > 1
			w = setout_conv(w,conv-2);
		elseif conv == 1
			error('Outlier reject not (yet) supported for this classifier')
		end
		w_out = w*rejectm(a*w,frac,rejname);
	otherwise
		error('Unknown reject type')
end

	
